/* -----------------------------------------------------------------------------
   (3) Globals
   -------------------------------------------------------------------------- */

/* -----------------------------------------------------------------------------
   Export settings
   -------------------------------------------------------------------------- */

// screen view
gl scrn "b(2) se(2) not wide compress nodep nocons star(+ 0.10 * 0.05 ** 0.01 *** 0.001)"
// variable sorting order
gl srtd "order(ne_months lne_fo *lne_type4 ne_weighted* concurrent tt_next closeness cv *.year)"

gl scrn "$scrn $srtd"

// table export
gl xprt "nonum nogap one lab mti star(+ 0.10 * 0.05 ** 0.01 *** 0.001) se(2)"
gl xprt "$xprt $srtd replace"

// table export, including first EP
gl xprt_fep = regexr("$xprt", " cv ", " cv first_ep ")

/* -----------------------------------------------------------------------------
   (1-4) Models 1-4
   -------------------------------------------------------------------------- */

// Eq. 1 -- time since last election + electoral rounds + FOPE
// Eq. 2 -- time since last election + electoral rounds + election type
// Eq. 3 -- time since last election + electoral contests + FOPE
// Eq. 4 -- time since last election + electoral contests + election type
gl eq1 "ne_months ne_weighted lne_fo"
gl eq2 "ne_months ne_weighted i.lne_type4"
gl eq3 "ne_months ne_weighted2 lne_fo"
gl eq4 "ne_months ne_weighted2 i.lne_type4"

// controls + year dummies
gl eq1 "$eq1 concurrent tt_next closeness cv i.year"
gl eq2 "$eq2 concurrent tt_next closeness cv i.year"
gl eq3 "$eq3 concurrent tt_next closeness cv i.year"
gl eq4 "$eq4 concurrent tt_next closeness cv i.year"

// main models (DV = % registered voters)
gl eq1 "voter_turnout $eq1"
gl eq2 "voter_turnout $eq2"
gl eq3 "voter_turnout $eq3"
gl eq4 "voter_turnout $eq4"

// restricted equations: single operationalizations of election cycle
// (reviewer 3, point 1)
// Restricted Eq. 1 -- time since last election (ne_months)
// Restricted Eq. 2 -- electoral rounds (ne_weighted)
// Restricted Eq. 3 -- electoral contests (ne_weighted2)
// Restricted Eq. 4 -- FOPE (lne_fo)
// Restricted Eq. 5 -- election type (lne_type4)
gl eqr1 = regexr("$eq1", "ne_m.*_fo", "ne_months")
gl eqr2 = regexr("$eq1", "ne_m.*_fo", "ne_weighted")
gl eqr3 = regexr("$eq1", "ne_m.*_fo", "ne_weighted2")
gl eqr4 = regexr("$eq1", "ne_m.*_fo", "lne_fo")
gl eqr5 = regexr("$eq1", "ne_m.*_fo", "i.lne_type4")

/* -----------------------------------------------------------------------------
   (5) Alternative CV predictor
   -------------------------------------------------------------------------- */

// DV = % voting-age population
gl cv1 = regexr("$eq1", " cv", " cv2")
gl cv2 = regexr("$eq2", " cv", " cv2")
gl cv3 = regexr("$eq3", " cv", " cv2")
gl cv4 = regexr("$eq4", " cv", " cv2")

/* -----------------------------------------------------------------------------
   (6) Controlling for first EP election
   -------------------------------------------------------------------------- */

gl fep1 = regexr("$eq1", " cv", " cv first_ep")
gl fep2 = regexr("$eq2", " cv", " cv first_ep")
gl fep3 = regexr("$eq3", " cv", " cv first_ep")
gl fep4 = regexr("$eq4", " cv", " cv first_ep")

/* -----------------------------------------------------------------------------
   (7-8) Sample subsets
   -------------------------------------------------------------------------- */

// excluding Germany and Italy (unsynchronised local elections)
gl ss1 if !inlist(iso3c, "DEU", "ITA")
count $ss1

// excluding France, Lithuania, Poland (semi-presidential regimes)
gl ss2 if !inlist(iso3c, "FRA", "LTU", "POL")
count $ss2

/* -----------------------------------------------------------------------------
   (9) Alternative DV: % voting-age population
   -------------------------------------------------------------------------- */

gl va1 = regexr("$eq1", "voter_turnout ", "vap_turnout ")
gl va2 = regexr("$eq2", "voter_turnout ", "vap_turnout ")
gl va3 = regexr("$eq3", "voter_turnout ", "vap_turnout ")
gl va4 = regexr("$eq4", "voter_turnout ", "vap_turnout ")

// done
